==> elara-core-1.2-sources.jar: org/tools4j/elara/loop/CommandPollerStep.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.loop;

import org.tools4j.elara.command.Command;
import org.tools4j.elara.log.PeekableMessageLog;
import org.tools4j.elara.plugin.base.BaseState;
import org.tools4j.nobark.loop.Step;

import static java.util.Objects.requireNonNull;

public class CommandPollerStep implements Step {

    private final BaseState baseState;
    private final PeekableMessageLog.PeekablePoller<? extends Command> commandPoller;
    private final PeekableMessageLog.PeekPollHandler<? super Command> handler;

    public CommandPollerStep(final BaseState baseState,
                             final PeekableMessageLog.PeekablePoller<? extends Command> commandPoller,
                             final PeekableMessageLog.PeekPollHandler<? super Command> handler) {
        this.baseState = requireNonNull(baseState);
        this.commandPoller = requireNonNull(commandPoller);
        this.handler = requireNonNull(handler);
    }

    @Override
    public boolean perform() {
        if (baseState.allEventsPolled()) {
            return commandPoller.peekOrPoll(handler) > 0;
        }
        //NOTE: only start playing new commands when state has been completely restored
        //      through replaying of events
        return false;
    }
}

==> elara-core-1.7-sources.jar: org/tools4j/elara/loop/CommandPollerStep.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 tools4j.org (Marco Terzer, Anton Anufriev)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.tools4j.elara.loop;

import org.tools4j.elara.log.MessageLog.Handler;
import org.tools4j.elara.log.MessageLog.Poller;
import org.tools4j.nobark.loop.Step;

import static java.util.Objects.requireNonNull;

public class CommandPollerStep implements Step {

    private final Poller commandPoller;
    private final Handler handler;

    public CommandPollerStep(final Poller commandPoller, final Handler handler) {
        this.commandPoller = requireNonNull(commandPoller);
        this.handler = requireNonNull(handler);
    }

    @Override
    public boolean perform() {
        return commandPoller.poll(handler) > 0;
    }
}
